==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AFullIdentClassName.h <==
// public final class soot.jimple.parser.node.AFullIdentClassName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b665880f1c5ca0b5 soot_jimple_parser_node_AFullIdentClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AFullIdentClassName_H_
#define _JC_soot_jimple_parser_node_AFullIdentClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFullIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs	_jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$refs	_jc_soot_jimple_parser_node_AFullIdentClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs	_jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$object	_jc_soot_jimple_parser_node_AFullIdentClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vmethods	_jc_soot_jimple_parser_node_AFullIdentClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtable	_jc_soot_jimple_parser_node_AFullIdentClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtype	_jc_soot_jimple_parser_node_AFullIdentClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$_init$380d98ce6a6acfb8(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
extern struct _jc_soot_jimple_parser_node_TFullIdentifier$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$getFullIdentifier$8528b94f9151a1c0(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$setFullIdentifier$6123d81342eac2ff(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$getFullIdentifier$8528b94f9151a1c0;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$setFullIdentifier$6123d81342eac2ff;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
	struct _jc_soot_jimple_parser_node_TFullIdentifier$object	*(*getFullIdentifier$8528b94f9151a1c0)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFullIdentifier$6123d81342eac2ff)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vmethods	soot_jimple_parser_node_AFullIdentClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TFullIdentifier$object	*__5ffullIdentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$refs {
    _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs	soot_jimple_parser_node_AFullIdentClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs	soot_jimple_parser_node_AFullIdentClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFullIdentClassName$object {
	_jc_soot_jimple_parser_node_AFullIdentClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFullIdentClassName$vtype _jc_soot_jimple_parser_node_AFullIdentClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFullIdentClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFullIdentClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFullIdentClassName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AFullIdentClassName.h <==
// public final class soot.jimple.parser.node.AFullIdentClassName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b665880f1c5ca0b5 soot_jimple_parser_node_AFullIdentClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AFullIdentClassName_H_
#define _JC_soot_jimple_parser_node_AFullIdentClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFullIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs	_jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$refs	_jc_soot_jimple_parser_node_AFullIdentClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs	_jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFullIdentClassName$object	_jc_soot_jimple_parser_node_AFullIdentClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vmethods	_jc_soot_jimple_parser_node_AFullIdentClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtable	_jc_soot_jimple_parser_node_AFullIdentClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtype	_jc_soot_jimple_parser_node_AFullIdentClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$_init$380d98ce6a6acfb8(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TFullIdentifier$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$getFullIdentifier$8528b94f9151a1c0(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFullIdentClassName$method$setFullIdentifier$6123d81342eac2ff(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFullIdentClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$getFullIdentifier$8528b94f9151a1c0;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$setFullIdentifier$6123d81342eac2ff;
extern _jc_method _jc_soot_jimple_parser_node_AFullIdentClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TFullIdentifier$object	*(*getFullIdentifier$8528b94f9151a1c0)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFullIdentifier$6123d81342eac2ff)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *, struct _jc_soot_jimple_parser_node_TFullIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vmethods	soot_jimple_parser_node_AFullIdentClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFullIdentClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TFullIdentifier$object	*__5ffullIdentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$refs {
    _jc_soot_jimple_parser_node_AFullIdentClassName$sub_refs	soot_jimple_parser_node_AFullIdentClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AFullIdentClassName$sub_nonrefs	soot_jimple_parser_node_AFullIdentClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFullIdentClassName$object {
	_jc_soot_jimple_parser_node_AFullIdentClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFullIdentClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFullIdentClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFullIdentClassName$vtype _jc_soot_jimple_parser_node_AFullIdentClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFullIdentClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFullIdentClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFullIdentClassName_H_ */
